pystages.cncrouter
==================

.. automodule:: pystages.cncrouter

.. autoclass:: CNCRouter
    :special-members: __init__
    :members:

.. autoclass:: CNCStatus
    :members:
    :undoc-members:

.. autoclass:: GRBLSetting
    :members:
    :undoc-members:

.. autoclass:: InvertMask
    :members:
    :undoc-members:

.. autoclass:: StatusReportMask
    :members:
    :undoc-members:
